require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_officeonlineserverfarm',
  dscmeta_resource_friendly_name: 'OfficeOnlineServerFarm',
  dscmeta_resource_name: 'MSFT_OfficeOnlineServerFarm',
  dscmeta_module_name: 'OfficeOnlineServerDsc',
  dscmeta_module_version: '1.2.0.0',
  docs: 'The DSC OfficeOnlineServerFarm resource type.
         Automatically generated from version 1.2.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_ssloffloaded: {
      type: 'Optional[Boolean]',
      desc: 'Indicates to the servers in the Office Web Apps Server farm that SSL is offloaded to the load balancer. When SSLOffloaded is enabled, web applications are bound to port 80 (HTTP) on the local server. However, HTML that references other resources, such as CSS or images, uses HTTPS URLs for those references.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_openfromuncenabled: {
      type: 'Optional[Boolean]',
      desc: 'Turns on or off the ability to use Online Viewers to view Office files from a UNC path.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_documentinfocachesize: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum number of document conversion records that are stored in a memory cache.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_loglocation: {
      type: 'Optional[String]',
      desc: 'Specifies the location on the local computer where activity logs are stored.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_cachelocation: {
      type: 'Optional[String]',
      desc: 'Specifies the location of the global disk cache that is used to store rendered image files.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_renderinglocalcachelocation: {
      type: 'Optional[String]',
      desc: 'Specifies the location of the temporary cache for use by the Word and PowerPoint Viewing Services.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_excelconnectionlifetime: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the duration, in seconds, of external data connections for Excel Web App. The default is 1800 seconds.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_exceludfsallowed: {
      type: 'Optional[Boolean]',
      desc: 'Activates user-defined functions for use with Web Excel.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_excelunusedobjectagemax: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The maximum time (in minutes) that inactive objects remain in the memory cache. Inactive objects are objects that are not used in a session.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_excelsessiontimeout: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the time, in seconds, that a session remains active in Excel Web App when there is no user activity.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_excelexternaldatacachelifetime: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifes the duration, in seconds, of the external data cache lifetime in Excel Web App. The default is 300 seconds.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_picturepastedisabled: {
      type: 'Optional[Boolean]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowhttpsecurestoreconnections: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that secure store connections can be made by using non-SSL connections (such as HTTP). The default is False.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_excelprivatebytesmax: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum private bytes, in megabytes, used by Excel Web App. When set to -1, the maximum private bytes use 50 percent of physical memory on the computer.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_exceldefaultworkbookcalcmode: {
      type: 'Optional[String]',
      desc: 'Specifies the calculation mode of workbooks.  Settings other than File override the workbook settings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceluseeffectiveusername: {
      type: 'Optional[Boolean]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_excelcachingunusedfiles: {
      type: 'Optional[Boolean]',
      desc: 'Enable caching of files that are no longer in use by Web Excel sessions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowhttp: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that IIS sites should be provisioned on port 80 for HTTP access. Use AllowHTTP only in environments where all computers require IPSEC (full encryption) or in test environments that do not contain sensitive files.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowoutboundhttp: {
      type: 'Optional[Boolean]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_recycleactiveprocesscount: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the number of files that a single Word or PowerPoint process can render before the process is recycled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_cachesizeingb: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum size of the global disk cache in gigabytes.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_externalurl: {
      type: 'Optional[String]',
      desc: 'Specifies the URL root that clients use to access the Office Web Apps Server farm from the Internet. In the case of a load-balanced, multiserver Office Web Apps Server farm, the external URL is bound to the IP address of the external-facing load balancer.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_translationserviceaddress: {
      type: 'Optional[String]',
      desc: 'Specifies the URL of the translation server that translation requests are sent to. The default is the Microsoft Translator online service. Typically you will not use this parameter unless you must change translation services.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxtranslationcharactercount: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum amount of characters a document can have in order to be translated.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_excelrestexternaldataenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether requests from the Representational State Transfer (REST) Application Programming Interface (API) are permitted to refresh external data connections.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_certificatename: {
      type: 'Optional[String]',
      desc: 'Specifies the friendly name of the certificate that Office Web Apps Server uses to create HTTPS bindings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxy: {
      type: 'Optional[String]',
      desc: 'Specifies the URL of the proxy server that is configured to allow HTTP requests to external sites. Typically configured in conjunction with the ClipartEnabled and TranslationEnabled parameters.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_excelchartandimagesizemax: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum size, in megabytes, of a chart or image that can be opened.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_clipartenabled: {
      type: 'Optional[Boolean]',
      desc: 'Enables support for inserting clip art from Office.com into Office documents. This feature requires server-to-web communication, configured either directly or by using a proxy that you specify by using the Proxy parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_s2scertificatename: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_internalurl: {
      type: 'String',
      desc: 'Specifies the URL root that clients use to access the Office Web Apps Server farm from the intranet.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logretentionindays: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the number of days that log entries are stored. Log entries older than the configured date are trimmed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_excelwarnondatarefresh: {
      type: 'Optional[Boolean]',
      desc: 'Turns off or on the warning dialog displayed when data refreshes in Excel Web App.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxmemorycachesizeinmb: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies, in megabytes, the maximum amount of memory that the rendering cache can use.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_removepersonalinformationfromlogs: {
      type: 'Optional[Boolean]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_excelworkbooksizemax: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum size, in megabytes, of a workbook that can be loaded.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_editingenabled: {
      type: 'Optional[Boolean]',
      desc: 'Enables support for editing in the browser. The default is False. Only set to True if you have the appropriate licensing to use the editing functionality.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_excelrequestdurationmax: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum duration, in seconds, for a single request in a session. After this time elapses, the request times out.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_excelconcurrentdatarequestspersessionmax: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum number of concurrent external data requests allowed in each session. If a session must issue more than this number of requests, additional requests must be queued. The scope of this setting is the logical server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_allowceip: {
      type: 'Optional[Boolean]',
      desc: 'Enables Customer Experience Improvement Program (CEIP) reporting on all servers in the Office Web Apps Server farm',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_farmou: {
      type: 'Optional[String]',
      desc: 'Specifies the name of the Active Directory organizational unit (OU) that servers must be a member of to join the Office Web Apps Server farm. Use this parameter to prevent unauthorized servers (that is, servers that are not in the OU) from joining an Office Web Apps Server farm.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_openfromurlthrottlingenabled: {
      type: 'Optional[Boolean]',
      desc: 'Throttles the number of open from URL requests from any given server in a time period. The default throttling values, which are not configurable, make sure that an Office Web Apps Server farm will not overwhelm a single server with requests for content to be viewed in the Online Viewers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_logverbosity: {
      type: 'Optional[String]',
      desc: 'Specifies how much information is stored in the trace log files.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_excelallowexternaldata: {
      type: 'Optional[Boolean]',
      desc: 'Enables the refresh of supported external data in Excel Web App workbooks where workbooks contain connections to external data. The default is True.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_translationserviceappid: {
      type: 'Optional[String]',
      desc: 'Specifies the application ID for the translation service. The default is the public application ID for Office Web Apps. Typically you will not use this parameter unless you have negotiated with Microsoft Translator for additional services and they have provided you with a private application ID.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_openfromurlenabled: {
      type: 'Optional[Boolean]',
      desc: 'Turns on or off the ability to use Online Viewers to view Office files from a URL or UNC path.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_excelabortonrefreshonopenfail: {
      type: 'Optional[Boolean]',
      desc: 'Specifies that the loading of a Web Excel file automatically fails if an automatic data refresh operation fails when the file is opened.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_excelautomaticvolatilefunctioncachelifetime: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum time, in seconds, that a computed value for a volatile function is cached for automatic recalculations.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_translationenabled: {
      type: 'Optional[Boolean]',
      desc: 'Enables support for automatic document translation using Microsoft Translator, an online service that translates text between languages. The translated file is shown in the Word Web App. Because Microsoft Translator is an online service, you must enable server-to-web communication directly or by using a proxy that you specify by using the Proxy parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_excelmemorycachethreshold: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The percentage of the Maximum Private Bytes that can be allocated to inactive objects. When the memory cache threshold is exceeded, cached objects that are not currently in use are released.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
  },
)
